@@ -13,7 +13,7 @@
  * @author     Florian Lippert <flo@syscp.org> (2003-2009)
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
- * @package    Settings
+ * @package    \Froxlor\Settings
  *
  */
 return array(
@@ -34,7 +34,10 @@ return array(
 						'nginx' => 'Nginx'
 					),
 					'save_method' => 'storeSettingField',
-					'plausibility_check_method' => 'checkPhpInterfaceSetting',
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkPhpInterfaceSetting'
+					),
 					'overview_option' => true
 				),
 				'system_apache_24' => array(
@@ -55,7 +58,7 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField',
-					'visible' => (Settings::Get('system.mod_fcgid') == 0 && Settings::Get('phpfpm.enabled') == 0),
+					'visible' => (\Froxlor\Settings::Get('system.mod_fcgid') == 0 && \Froxlor\Settings::Get('phpfpm.enabled') == 0),
 					'websrv_avail' => array(
 						'apache2'
 					)
@@ -71,7 +74,18 @@ return array(
 						'apache2',
 						'nginx'
 					),
-					'visible' => Settings::Get('system.use_ssl')
+					'visible' => \Froxlor\Settings::Get('system.use_ssl')
+				),
+				'system_dhparams_file' => array(
+					'label' => $lng['serversettings']['dhparams_file'],
+					'settinggroup' => 'system',
+					'varname' => 'dhparams_file',
+					'type' => 'string',
+					'string_type' => 'file',
+					'string_emptyallowed' => true,
+					'default' => '',
+					'save_method' => 'storeSettingField',
+					'visible' => \Froxlor\Settings::Get('system.use_ssl')
 				),
 				'system_httpuser' => array(
 					'label' => $lng['admin']['webserver_user'],
@@ -177,6 +191,29 @@ return array(
 						'apache2'
 					)
 				),
+				'system_errorlog_level' => array(
+					'label' => $lng['serversettings']['errorlog_level'],
+					'settinggroup' => 'system',
+					'varname' => 'errorlog_level',
+					'type' => 'option',
+					'default' => (\Froxlor\Settings::Get('system.webserver') == 'nginx' ? 'error' : 'warn'),
+					'option_mode' => 'one',
+					'option_options' => array(
+						'emerg' => 'emerg',
+						'alert' => 'alert',
+						'crit' => 'crit',
+						'error' => 'error',
+						'warn' => 'warn',
+						'notice' => 'notice',
+						'info' => 'info',
+						'debug' => 'debug'
+					),
+					'save_method' => 'storeSettingField',
+					'websrv_avail' => array(
+						'apache2',
+						'nginx'
+					)
+				),
 				'system_customersslpath' => array(
 					'label' => $lng['serversettings']['customerssl_directory'],
 					'settinggroup' => 'system',
@@ -213,6 +250,23 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingField'
 				),
+				'system_default_sslvhostconf' => array(
+					'label' => $lng['serversettings']['default_sslvhostconf'],
+					'settinggroup' => 'system',
+					'varname' => 'default_sslvhostconf',
+					'type' => 'text',
+					'default' => '',
+					'save_method' => 'storeSettingField',
+					'visible' => \Froxlor\Settings::Get('system.use_ssl') == 1
+				),
+				'system_include_default_vhostconf' => array(
+					'label' => $lng['serversettings']['includedefault_sslvhostconf'],
+					'settinggroup' => 'system',
+					'varname' => 'include_default_vhostconf',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+				),
 				'system_apache_globaldiropt' => array(
 					'label' => $lng['serversettings']['apache_globaldiropt'],
 					'settinggroup' => 'system',
@@ -220,7 +274,7 @@ return array(
 					'type' => 'text',
 					'default' => '',
 					'save_method' => 'storeSettingField',
-					'visible' => (Settings::Get('system.mod_fcgid') == 0 && Settings::Get('phpfpm.enabled') == 0),
+					'visible' => (\Froxlor\Settings::Get('system.mod_fcgid') == 0 && \Froxlor\Settings::Get('phpfpm.enabled') == 0),
 					'websrv_avail' => array(
 						'apache2'
 					)
@@ -334,7 +388,7 @@ return array(
 					'type' => 'option',
 					'default' => '1',
 					'option_mode' => 'one',
-					'option_options_method' => 'getRedirectCodes',
+					'option_options_method' => array('\\Froxlor\\Domain\\Domain', 'getRedirectCodes'),
 					'save_method' => 'storeSettingField'
 				)
 			)
