@@ -16,7 +16,6 @@
  * @package    Settings
  *
  */
-
 return array(
 	'groups' => array(
 		'statistics' => array(
@@ -29,17 +28,21 @@ return array(
 					'type' => 'option',
 					'default' => 2,
 					'option_mode' => 'one',
-					'option_options' => array(0 => $lng['admin']['webalizer']['normal'], 1 => $lng['admin']['webalizer']['quiet'], 2 => $lng['admin']['webalizer']['veryquiet']),
-					'save_method' => 'storeSettingField',
+					'option_options' => array(
+						0 => $lng['admin']['webalizer']['normal'],
+						1 => $lng['admin']['webalizer']['quiet'],
+						2 => $lng['admin']['webalizer']['veryquiet']
 					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_awstats_enabled' => array(
 					'label' => $lng['serversettings']['awstats_enabled'],
 					'settinggroup' => 'system',
 					'varname' => 'awstats_enabled',
 					'type' => 'bool',
 					'default' => false,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_awstats_path' => array(
 					'label' => $lng['serversettings']['awstats_path'],
 					'settinggroup' => 'system',
@@ -47,8 +50,8 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => '/usr/bin/',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_awstats_awstatspath' => array(
 					'label' => $lng['serversettings']['awstats_awstatspath'],
 					'settinggroup' => 'system',
@@ -56,8 +59,8 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => '/usr/bin/',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_awstats_conf' => array(
 					'label' => $lng['serversettings']['awstats_conf'],
 					'settinggroup' => 'system',
@@ -65,8 +68,8 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => '/etc/awstats/',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_awstats_icons' => array(
 					'label' => $lng['serversettings']['awstats_icons'],
 					'settinggroup' => 'system',
@@ -74,11 +77,11 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => '/usr/share/awstats/icon/',
-					'save_method' => 'storeSettingField',
-					)
+					'save_method' => 'storeSettingField'
 				)
 			)
 		)
-	);
+	)
+);
 
 ?>
\ No newline at end of file
