@@ -1,6 +1,8 @@
 <?php
-if (! defined('AREA'))
-	die('You cannot access this file directly!');
+if (! defined('AREA')) {
+	header("Location: index.php");
+	exit();
+}
 
 /**
  * This file is part of the Froxlor project.
@@ -14,55 +16,38 @@ if (! defined('AREA'))
  * @author Froxlor team <team@froxlor.org> (2016-)
  * @license GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package Panel
- *
+ *         
  */
 
+use Froxlor\Database\Database;
+use Froxlor\Settings;
+use Froxlor\Api\Commands\Certificates as Certificates;
+
 // This file is being included in admin_domains and customer_domains
-	// and therefore does not need to require lib/init.php
+// and therefore does not need to require lib/init.php
 
-$del_stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` WHERE id = :id");
 $success_message = "";
 
 // do the delete and then just show a success-message and the certificates list again
 if ($action == 'delete') {
 	$id = isset($_GET['id']) ? (int) $_GET['id'] : 0;
 	if ($id > 0) {
-		$chk = (AREA == 'admin' && $userinfo['customers_see_all'] == '1') ? true : false;
-		if (AREA == 'customer') {
-			$chk_stmt = Database::prepare("
-				SELECT d.domain FROM `" . TABLE_PANEL_DOMAINS . "` d
-				LEFT JOIN `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` s ON s.domainid = d.id
-				WHERE s.`id` = :id AND d.`customerid` = :cid
-			");
-			$chk = Database::pexecute_first($chk_stmt, array(
-				'id' => $id,
-				'cid' => $userinfo['customerid']
-			));
-		} elseif (AREA == 'admin' && $userinfo['customers_see_all'] == '0') {
-			$chk_stmt = Database::prepare("
-				SELECT d.domain FROM `" . TABLE_PANEL_DOMAINS . "` d
-				LEFT JOIN `" . TABLE_PANEL_DOMAIN_SSL_SETTINGS . "` s ON s.domainid = d.id
-				WHERE s.`id` = :id AND d.`adminid` = :aid
-			");
-			$chk = Database::pexecute_first($chk_stmt, array(
-				'id' => $id,
-				'aid' => $userinfo['adminid']
-			));
-		}
-		if ($chk !== false) {
-			Database::pexecute($del_stmt, array(
+		try {
+			$json_result = Certificates::getLocal($userinfo, array(
 				'id' => $id
-			));
+			))->delete();
 			$success_message = sprintf($lng['domains']['ssl_certificate_removed'], $id);
+		} catch (Exception $e) {
+			\Froxlor\UI\Response::dynamic_error($e->getMessage());
 		}
 	}
 }
 
-$log->logAction(USR_ACTION, LOG_NOTICE, "viewed domains::ssl_certificates");
+$log->logAction(\Froxlor\FroxlorLogger::USR_ACTION, LOG_NOTICE, "viewed domains::ssl_certificates");
 $fields = array(
 	'd.domain' => $lng['domains']['domainname']
 );
-$paging = new paging($userinfo, TABLE_PANEL_DOMAIN_SSL_SETTINGS, $fields);
+$paging = new \Froxlor\UI\Paging($userinfo, TABLE_PANEL_DOMAIN_SSL_SETTINGS, $fields);
 
 // select all my (accessable) certificates
 $certs_stmt_query = "SELECT s.*, d.domain, d.letsencrypt, c.customerid, c.loginname
@@ -101,7 +86,7 @@ if (count($all_certs) == 0) {
 	);
 	$searchcode = "";
 	$pagingcode = "";
-	eval("\$certificates.=\"" . getTemplate("ssl_certificates/certs_error", true) . "\";");
+	eval("\$certificates.=\"" . \Froxlor\UI\Template::getTemplate("ssl_certificates/certs_error", true) . "\";");
 } else {
 	$paging->setEntries(count($all_certs));
 	$sortcode = $paging->getHtmlSortCode($lng);
@@ -121,9 +106,13 @@ if (count($all_certs) == 0) {
 
 			if (empty($cert['domain']) || empty($cert['ssl_cert_file'])) {
 				// no domain found to the entry or empty entry - safely delete it from the DB
-				Database::pexecute($del_stmt, array(
-					'id' => $cert['id']
-				));
+				try {
+					Certificates::getLocal($userinfo, array(
+						'id' => $cert['id']
+					))->delete();
+				} catch (Exception $e) {
+					// do nothing
+				}
 				continue;
 			}
 
@@ -164,15 +153,15 @@ if (count($all_certs) == 0) {
 					}
 				}
 
-				$row = htmlentities_array($cert);
-				eval("\$certificates.=\"" . getTemplate("ssl_certificates/certs_cert", true) . "\";");
+				$row = \Froxlor\PhpHelper::htmlentitiesArray($cert);
+				eval("\$certificates.=\"" . \Froxlor\UI\Template::getTemplate("ssl_certificates/certs_cert", true) . "\";");
 			} else {
 				$message = sprintf($lng['domains']['ssl_certificate_error'], $cert['domain']);
-				eval("\$certificates.=\"" . getTemplate("ssl_certificates/certs_error", true) . "\";");
+				eval("\$certificates.=\"" . \Froxlor\UI\Template::getTemplate("ssl_certificates/certs_error", true) . "\";");
 			}
 		} else {
 			continue;
 		}
 	}
 }
-eval("echo \"" . getTemplate("ssl_certificates/certs_list", true) . "\";");
+eval("echo \"" . \Froxlor\UI\Template::getTemplate("ssl_certificates/certs_list", true) . "\";");
